@@ -16,16 +16,21 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.vpcaccess_v1.services.vpc_access_service import pagers
@@ -107,6 +112,42 @@ class VpcAccessServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return VpcAccessServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> VpcAccessServiceTransport:
         """Returns the transport used by the client instance.
@@ -169,20 +210,45 @@ class VpcAccessServiceAsyncClient:
 
     async def create_connector(
         self,
-        request: vpc_access.CreateConnectorRequest = None,
+        request: Union[vpc_access.CreateConnectorRequest, dict] = None,
         *,
         parent: str = None,
         connector_id: str = None,
         connector: vpc_access.Connector = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a Serverless VPC Access connector, returns an
         operation.
 
+
+        .. code-block::
+
+            from google.cloud import vpcaccess_v1
+
+            def sample_create_connector():
+                # Create a client
+                client = vpcaccess_v1.VpcAccessServiceClient()
+
+                # Initialize request argument(s)
+                request = vpcaccess_v1.CreateConnectorRequest(
+                    parent="parent_value",
+                    connector_id="connector_id_value",
+                )
+
+                # Make the request
+                operation = client.create_connector(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.vpcaccess_v1.types.CreateConnectorRequest`):
+            request (Union[google.cloud.vpcaccess_v1.types.CreateConnectorRequest, dict]):
                 The request object. Request for creating a Serverless
                 VPC Access connector.
             parent (:class:`str`):
@@ -221,7 +287,7 @@ class VpcAccessServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, connector_id, connector])
         if request is not None and has_flattened_params:
@@ -271,18 +337,38 @@ class VpcAccessServiceAsyncClient:
 
     async def get_connector(
         self,
-        request: vpc_access.GetConnectorRequest = None,
+        request: Union[vpc_access.GetConnectorRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> vpc_access.Connector:
         r"""Gets a Serverless VPC Access connector. Returns NOT_FOUND if the
         resource does not exist.
 
+
+        .. code-block::
+
+            from google.cloud import vpcaccess_v1
+
+            def sample_get_connector():
+                # Create a client
+                client = vpcaccess_v1.VpcAccessServiceClient()
+
+                # Initialize request argument(s)
+                request = vpcaccess_v1.GetConnectorRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_connector(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.vpcaccess_v1.types.GetConnectorRequest`):
+            request (Union[google.cloud.vpcaccess_v1.types.GetConnectorRequest, dict]):
                 The request object. Request for getting a Serverless VPC
                 Access connector.
             name (:class:`str`):
@@ -305,7 +391,7 @@ class VpcAccessServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -343,17 +429,37 @@ class VpcAccessServiceAsyncClient:
 
     async def list_connectors(
         self,
-        request: vpc_access.ListConnectorsRequest = None,
+        request: Union[vpc_access.ListConnectorsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListConnectorsAsyncPager:
         r"""Lists Serverless VPC Access connectors.
 
+        .. code-block::
+
+            from google.cloud import vpcaccess_v1
+
+            def sample_list_connectors():
+                # Create a client
+                client = vpcaccess_v1.VpcAccessServiceClient()
+
+                # Initialize request argument(s)
+                request = vpcaccess_v1.ListConnectorsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_connectors(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.vpcaccess_v1.types.ListConnectorsRequest`):
+            request (Union[google.cloud.vpcaccess_v1.types.ListConnectorsRequest, dict]):
                 The request object. Request for listing Serverless VPC
                 Access connectors in a location.
             parent (:class:`str`):
@@ -379,7 +485,7 @@ class VpcAccessServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -423,18 +529,42 @@ class VpcAccessServiceAsyncClient:
 
     async def delete_connector(
         self,
-        request: vpc_access.DeleteConnectorRequest = None,
+        request: Union[vpc_access.DeleteConnectorRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a Serverless VPC Access connector. Returns NOT_FOUND if
         the resource does not exist.
 
+
+        .. code-block::
+
+            from google.cloud import vpcaccess_v1
+
+            def sample_delete_connector():
+                # Create a client
+                client = vpcaccess_v1.VpcAccessServiceClient()
+
+                # Initialize request argument(s)
+                request = vpcaccess_v1.DeleteConnectorRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_connector(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.vpcaccess_v1.types.DeleteConnectorRequest`):
+            request (Union[google.cloud.vpcaccess_v1.types.DeleteConnectorRequest, dict]):
                 The request object. Request for deleting a Serverless
                 VPC Access connector.
             name (:class:`str`):
@@ -470,7 +600,7 @@ class VpcAccessServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
